<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="tr">
<context>
    <name>AirplaneModeItem</name>
    <message>
        <source>Airplane mode enabled</source>
        <translation>Uçak kipi etkin</translation>
    </message>
    <message>
        <source>Airplane mode disabled</source>
        <translation>Uçak kipi devre dışı bırakıldı</translation>
    </message>
    <message>
        <source>Disable</source>
        <translation>Devre dışı bırak</translation>
    </message>
    <message>
        <source>Enable</source>
        <translation>Etkinleştir</translation>
    </message>
    <message>
        <source>Airplane Mode</source>
        <translation>Uçak Kipi</translation>
    </message>
    <message>
        <source>Airplane mode settings</source>
        <translation>Uçak Kipi ayarları</translation>
    </message>
</context>
<context>
    <name>AirplaneModePlugin</name>
    <message>
        <source>Airplane Mode</source>
        <translation>Uçak Kipi</translation>
    </message>
</context>
<context>
    <name>BluetoothAdapterItem</name>
    <message>
        <source>My Devices</source>
        <translation>Cihazlarım</translation>
    </message>
</context>
<context>
    <name>BluetoothApplet</name>
    <message>
        <source>Bluetooth settings</source>
        <translation>Bluetooth ayarları</translation>
    </message>
    <message>
        <source>Turned off</source>
        <translation>Kapatıldı</translation>
    </message>
    <message>
        <source>Disable [Airplane Mode](#) first if you want to connect to a Bluetooth</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>BluetoothItem</name>
    <message>
        <source>Turn off</source>
        <translation>Kapat</translation>
    </message>
    <message>
        <source>Turn on</source>
        <translation>Aç</translation>
    </message>
    <message>
        <source>Bluetooth settings</source>
        <translation>Bluetooth ayarları</translation>
    </message>
    <message>
        <source>%1 connected</source>
        <translation>%1 bağlandı</translation>
    </message>
    <message>
        <source>Connecting...</source>
        <translation>Bağlanıyor...</translation>
    </message>
    <message>
        <source>Bluetooth</source>
        <translation>Bluetooth</translation>
    </message>
    <message>
        <source>Turned off</source>
        <translation>Kapat</translation>
    </message>
    <message>
        <source>Connected %1</source>
        <translation>Bağlandı %1</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>Bağlı değil</translation>
    </message>
    <message>
        <source>Off</source>
        <translation>Kapalı</translation>
    </message>
</context>
<context>
    <name>BluetoothPlugin</name>
    <message>
        <source>Bluetooth</source>
        <translation>Bluetooth</translation>
    </message>
</context>
<context>
    <name>BrightnessApplet</name>
    <message>
        <source>Brightness</source>
        <translation>Parlaklık</translation>
    </message>
    <message>
        <source>Display settings</source>
        <translation>Ekran ayarları</translation>
    </message>
</context>
<context>
    <name>BrightnessItem</name>
    <message>
        <source>Display settings</source>
        <translation>Ekran ayarları</translation>
    </message>
</context>
<context>
    <name>BrightnessPlugin</name>
    <message>
        <source>Brightness</source>
        <translation>Parlaklık</translation>
    </message>
</context>
<context>
    <name>CWeekWidget</name>
    <message>
        <source>Sun</source>
        <translation>Pazar</translation>
    </message>
    <message>
        <source>Mon</source>
        <translation>Pazartesi</translation>
    </message>
    <message>
        <source>Tue</source>
        <translation>Salı</translation>
    </message>
    <message>
        <source>Wed</source>
        <translation>Çarşamba</translation>
    </message>
    <message>
        <source>Thu</source>
        <translation>Perşembe</translation>
    </message>
    <message>
        <source>Fri</source>
        <translation>Cuma</translation>
    </message>
    <message>
        <source>Sat</source>
        <translation>Cumartesi</translation>
    </message>
</context>
<context>
    <name>DBusAdaptors</name>
    <message>
        <source>Add keyboard layout</source>
        <translation>Klavye düzeni ekle</translation>
    </message>
</context>
<context>
    <name>DatetimePlugin</name>
    <message>
        <source>Datetime</source>
        <translation>Tarih Saat</translation>
    </message>
    <message>
        <source>12-hour time</source>
        <translation>12-saatlik zaman</translation>
    </message>
    <message>
        <source>24-hour time</source>
        <translation>24-saatlik zaman</translation>
    </message>
    <message>
        <source>Time settings</source>
        <translation>Zaman ayarları</translation>
    </message>
    <message>
        <source>Open the calendar</source>
        <translation>Takvimi aç</translation>
    </message>
</context>
<context>
    <name>DatetimeWidget</name>
    <message>
        <source>Monday</source>
        <translation>Pazartesi</translation>
    </message>
    <message>
        <source>Tuesday</source>
        <translation>Salı</translation>
    </message>
    <message>
        <source>Wednesday</source>
        <translation>Çarşamba</translation>
    </message>
    <message>
        <source>Thursday</source>
        <translation>Perşembe</translation>
    </message>
    <message>
        <source>Friday</source>
        <translation>Cuma</translation>
    </message>
    <message>
        <source>Saturday</source>
        <translation>Cumartesi</translation>
    </message>
    <message>
        <source>Sunday</source>
        <translation>Pazar</translation>
    </message>
    <message>
        <source>monday</source>
        <translation>pazartesi</translation>
    </message>
    <message>
        <source>tuesday</source>
        <translation>Salı</translation>
    </message>
    <message>
        <source>wednesday</source>
        <translation>Çarşamba</translation>
    </message>
    <message>
        <source>thursday</source>
        <translation>Perşembe</translation>
    </message>
    <message>
        <source>friday</source>
        <translation>Cuma</translation>
    </message>
    <message>
        <source>saturday</source>
        <translation>Cumartesi</translation>
    </message>
    <message>
        <source>sunday</source>
        <translation>pazar</translation>
    </message>
</context>
<context>
    <name>DeviceControlWidget</name>
    <message>
        <source>Other Devices</source>
        <translation>Diğer Aygıtlar</translation>
    </message>
</context>
<context>
    <name>DndModeItem</name>
    <message>
        <source>DND Mode</source>
        <translation>RHT Kipi</translation>
    </message>
    <message>
        <source>DND mode settings</source>
        <translation>RHT kipi ayarları</translation>
    </message>
    <message>
        <source>Disable</source>
        <translation>Devre Dışı </translation>
    </message>
    <message>
        <source>Enable</source>
        <translation>Etkinleştir</translation>
    </message>
    <message>
        <source>DND mode enabled</source>
        <translation>RHT kipi etkinleştirildi</translation>
    </message>
    <message>
        <source>DND mode disabled</source>
        <translation>RHT kipi devre dışı bırakıldı</translation>
    </message>
</context>
<context>
    <name>DndModePlugin</name>
    <message>
        <source>DND Mode</source>
        <translation>RHT Kipi</translation>
    </message>
</context>
<context>
    <name>EyeComfortModeItem</name>
    <message>
        <source>Eye Comfort</source>
        <translation>Göz Rahatlığı</translation>
    </message>
    <message>
        <source>Eye comfort enabled</source>
        <translation>Göz rahatlığı etkinleştirildi</translation>
    </message>
    <message>
        <source>Eye comfort disabled</source>
        <translation>Göz rahatlığı devre dışı bırakıldı</translation>
    </message>
    <message>
        <source>Display settings</source>
        <translation>Ekran ayarları</translation>
    </message>
    <message>
        <source>Eye comfort</source>
        <translation>Göz Rahatlığı</translation>
    </message>
    <message>
        <source>Theme</source>
        <translation>Tema</translation>
    </message>
    <message>
        <source>On</source>
        <translation>Açık</translation>
    </message>
    <message>
        <source>Off</source>
        <translation>Kapalı</translation>
    </message>
    <message>
        <source>Light</source>
        <translation>Açık</translation>
    </message>
    <message>
        <source>Dark</source>
        <translation>Koyu</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Otomatik</translation>
    </message>
    <message>
        <source>Disable eye comfort</source>
        <translation>Göz rahatlığı devre dışı bırak</translation>
    </message>
    <message>
        <source>Enable eye comfort</source>
        <translation>Göz rahatlığını enkileştir</translation>
    </message>
    <message>
        <source>Display Settings</source>
        <translation>Ekran Ayarları</translation>
    </message>
    <message>
        <source>Theme: Light</source>
        <translation>Tema: Açık</translation>
    </message>
    <message>
        <source>Theme: Dark</source>
        <translation>Tema: Koyu</translation>
    </message>
    <message>
        <source>Theme: Auto</source>
        <translation>Tema: Otomatik</translation>
    </message>
    <message>
        <source>Visual effect</source>
        <translation>Görsel efekt</translation>
    </message>
</context>
<context>
    <name>EyeComfortmodeApplet</name>
    <message>
        <source>Light</source>
        <translation>Açık</translation>
    </message>
    <message>
        <source>Dark</source>
        <translation>Koyu</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Otomatik</translation>
    </message>
    <message>
        <source>Theme</source>
        <translation>Tema</translation>
    </message>
</context>
<context>
    <name>NotificationPlugin</name>
    <message>
        <source>No messages</source>
        <translation>İleti yok</translation>
    </message>
    <message>
        <source>Notification settings</source>
        <translation>Bildirim ayarları</translation>
    </message>
    <message>
        <source>Notifications</source>
        <translation>Bildirim</translation>
    </message>
    <message>
        <source>Turn off DND mode</source>
        <translation>RHT kipini kapat</translation>
    </message>
    <message>
        <source>Turn on DND mode</source>
        <translation>RHT kipini aç</translation>
    </message>
    <message>
        <source>Notification</source>
        <translation>Bildirim</translation>
    </message>
</context>
<context>
    <name>OnboardPlugin</name>
    <message>
        <source>Onboard</source>
        <translation>Ekran Klavyesi</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Ayarlar</translation>
    </message>
</context>
<context>
    <name>PerformanceModeController</name>
    <message>
        <source>High Performance</source>
        <translation>Yüksek Performans</translation>
    </message>
    <message>
        <source>Balanced</source>
        <translation>Dengeli</translation>
    </message>
    <message>
        <source>Power Saver</source>
        <translation>Güç Tasarrufu</translation>
    </message>
    <message>
        <source>Balance Performance</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>PowerApplet</name>
    <message>
        <source>Power</source>
        <translation>Güç</translation>
    </message>
</context>
<context>
    <name>PowerPlugin</name>
    <message>
        <source>Power settings</source>
        <translation>Güç ayarları</translation>
    </message>
    <message>
        <source>Capacity %1, %2 min remaining</source>
        <translation>%1 ve azalıyor, %2 dakika kaldı</translation>
    </message>
    <message>
        <source>Capacity %1, %2 hr %3 min remaining</source>
        <translation>%1 ve azalıyor, %2 saat %3 dakika kaldı</translation>
    </message>
    <message>
        <source>Charging %1, %2 min until full</source>
        <translation>%1 ve doluyor, tam dolmaya %2 dakika kaldı</translation>
    </message>
    <message>
        <source>Charging %1, %2 hr %3 min until full</source>
        <translation>%1 doluyor, doluma %2 saat %3 dakika var</translation>
    </message>
    <message>
        <source>Capacity %1</source>
        <translation>Kapasite %1</translation>
    </message>
    <message>
        <source>Charging %1</source>
        <translation>%1 Şarj Oluyor</translation>
    </message>
    <message>
        <source>Capacity %1 ...</source>
        <translation>Kapasite %1 ...</translation>
    </message>
    <message>
        <source>Capacity %1, fully charged</source>
        <translation>Kapasite %1, tam şarjlı</translation>
    </message>
    <message>
        <source>Capacity %1, not charging</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Battery</source>
        <translation>Pil</translation>
    </message>
    <message>
        <source>Charging, calculating estimated charging time</source>
        <translation>Şarj, tahmini şarj süresinin hesaplanıyor</translation>
    </message>
    <message>
        <source>Calculating remaining usage time</source>
        <translation>Kalan kullanım süresinin hesaplanıyor</translation>
    </message>
    <message>
        <source>%1 min remaining</source>
        <translation>%1 dakika kaldı</translation>
    </message>
    <message>
        <source>%1 hr %2 min remaining</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Not charging</source>
        <translation>Şarj Etmiyor</translation>
    </message>
    <message>
        <source>Fully charged</source>
        <translation>Tam dolu</translation>
    </message>
    <message>
        <source>Charging, %1 min until full</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Charging, %1 hr %2 min until full</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Capacity %1, %2 hr remaining</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>%1 hr remaining</source>
        <translation>%1 saat kaldı</translation>
    </message>
    <message>
        <source>Charging %1, %2 hr until full</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Charging, %1 hr until full</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>PowerStatusWidget</name>
    <message>
        <source>Power settings</source>
        <translation>Güç ayarları</translation>
    </message>
</context>
<context>
    <name>QuickPanelWidget</name>
    <message>
        <source>Music</source>
        <translation>Müzik</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>Bilinmeyen</translation>
    </message>
</context>
<context>
    <name>ShutdownPlugin</name>
    <message>
        <source>Shut down</source>
        <translation>Kapat</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Askıya al</translation>
    </message>
    <message>
        <source>Hibernate</source>
        <translation>Uyut</translation>
    </message>
    <message>
        <source>Lock</source>
        <translation>Kilitle</translation>
    </message>
    <message>
        <source>Log out</source>
        <translation>Oturumu kapat</translation>
    </message>
    <message>
        <source>Power settings</source>
        <translation>Güç ayarları</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Yeniden başlat</translation>
    </message>
    <message>
        <source>Update and Shut Down</source>
        <translation>Güncelleştir ve Kapat</translation>
    </message>
    <message>
        <source>Update and Reboot</source>
        <translation>Güncelleştir ve Yeniden Başlat</translation>
    </message>
    <message>
        <source>Shut Down</source>
        <translation>Kapat</translation>
    </message>
    <message>
        <source>Switch user</source>
        <translation>Kullanıcı değiştir</translation>
    </message>
</context>
<context>
    <name>SidebarCalendarWidget</name>
    <message>
        <source>Today</source>
        <translation>Bugün</translation>
    </message>
    <message>
        <source>Lunar</source>
        <translation>Ay</translation>
    </message>
    <message>
        <source>y</source>
        <translation>y</translation>
    </message>
    <message>
        <source>m</source>
        <translation>a</translation>
    </message>
    <message>
        <source>d</source>
        <translation>d</translation>
    </message>
    <message>
        <source>Monday</source>
        <translation>Pazartesi</translation>
    </message>
    <message>
        <source>Tuesday</source>
        <translation>Salı</translation>
    </message>
    <message>
        <source>Wednesday</source>
        <translation>Çarşamba</translation>
    </message>
    <message>
        <source>Thursday</source>
        <translation>Perşembe</translation>
    </message>
    <message>
        <source>Friday</source>
        <translation>Cuma</translation>
    </message>
    <message>
        <source>Saturday</source>
        <translation>Cumartesi</translation>
    </message>
    <message>
        <source>Sunday</source>
        <translation>Pazar</translation>
    </message>
    <message>
        <source>Jan</source>
        <translation>Oca</translation>
    </message>
    <message>
        <source>Feb</source>
        <translation>Şub</translation>
    </message>
    <message>
        <source>Mar</source>
        <translation>Mar</translation>
    </message>
    <message>
        <source>Apr</source>
        <translation>Nis</translation>
    </message>
    <message>
        <source>May</source>
        <translation>May</translation>
    </message>
    <message>
        <source>Jun</source>
        <translation>Haz</translation>
    </message>
    <message>
        <source>Jul</source>
        <translation>Tem</translation>
    </message>
    <message>
        <source>Aug</source>
        <translation>Ağu</translation>
    </message>
    <message>
        <source>Sept</source>
        <translation>Eyl</translation>
    </message>
    <message>
        <source>Oct</source>
        <translation>Eki</translation>
    </message>
    <message>
        <source>Nov</source>
        <translation>Kas</translation>
    </message>
    <message>
        <source>Dec</source>
        <translation>Ara</translation>
    </message>
    <message>
        <source>Open the calendar</source>
        <translation>Takvimi aç</translation>
    </message>
    <message>
        <source>monday</source>
        <translation>pazartesi</translation>
    </message>
    <message>
        <source>tuesday</source>
        <translation>Salı</translation>
    </message>
    <message>
        <source>wednesday</source>
        <translation>Çarşamba</translation>
    </message>
    <message>
        <source>thursday</source>
        <translation>Perşembe</translation>
    </message>
    <message>
        <source>friday</source>
        <translation>Cuma</translation>
    </message>
    <message>
        <source>saturday</source>
        <translation>Cumartesi</translation>
    </message>
    <message>
        <source>sunday</source>
        <translation>pazar</translation>
    </message>
</context>
<context>
    <name>SoundApplet</name>
    <message>
        <source>Volume</source>
        <translation>Ses</translation>
    </message>
    <message>
        <source>Output</source>
        <translation>Çıkış</translation>
    </message>
    <message>
        <source>Sound settings</source>
        <translation>Ses ayarları</translation>
    </message>
</context>
<context>
    <name>SoundPlugin</name>
    <message>
        <source>Sound</source>
        <translation>Ses</translation>
    </message>
</context>
<context>
    <name>SoundView</name>
    <message>
        <source>Unmute</source>
        <translation>Sesi aç</translation>
    </message>
    <message>
        <source>Mute</source>
        <translation>Sesi kapat</translation>
    </message>
    <message>
        <source>Sound settings</source>
        <translation>Ses ayarları</translation>
    </message>
    <message>
        <source>No output devices</source>
        <translation>Çıkış cihazı yok</translation>
    </message>
    <message>
        <source>Volume %1</source>
        <translation>Ses %1</translation>
    </message>
</context>
</TS>